nengo\_spa\.algebras
====================

.. currentmodule:: nengo_spa.algebras

The following items are re-exported by ``nengo_spa.algebras``:

.. autosummary::

   base.AbstractAlgebra
   base.CommonProperties
   base.ElementSidedness
   hrr_algebra.HrrAlgebra
   hrr_algebra.HrrProperties
   vtb_algebra.VtbAlgebra
   vtb_algebra.VtbProperties
   tvtb_algebra.TvtbAlgebra
   tvtb_algebra.TvtbProperties


Base classes
------------

.. automodule:: nengo_spa.algebras.base
   :members:
   :undoc-members:

   .. autosummary::

      AbstractAlgebra
      AbstractSign
      CommonProperties
      ElementSidedness
      GenericSign


Holographic reduced representations (HRR)
-----------------------------------------

.. automodule:: nengo_spa.algebras.hrr_algebra
   :members:
   :undoc-members:

   .. autosummary::

      HrrAlgebra
      HrrProperties
      HrrSign


Vector-derived transformation binding (VTB)
-------------------------------------------

.. automodule:: nengo_spa.algebras.vtb_algebra
   :members:
   :undoc-members:

   .. autosummary::

      VtbAlgebra
      VtbProperties
      VtbSign


Transposed vector-derived transformation binding (TVTB)
-------------------------------------------------------

.. automodule:: nengo_spa.algebras.tvtb_algebra
   :members:
   :undoc-members:

   .. autosummary::

      TvtbAlgebra
      TvtbProperties
      TvtbSign
